#
# ovirt-hosted-engine-setup -- ovirt hosted engine setup
# Copyright (C) 2013-2018 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

%global         package_version 2.3.11
%global         ovirt_hosted_engine_setup_templates %{_datadir}/%{name}/templates
%global         ovirt_hosted_engine_setup_scripts %{_datadir}/%{name}/scripts
%global         vdsmhooksdir %{_libexecdir}/vdsm/hooks


Summary:        oVirt Hosted Engine setup tool
Name:           ovirt-hosted-engine-setup
Version:        2.3.11
Release:        1%{?release_suffix}%{?dist}
License:        LGPLv2+
URL:            http://www.ovirt.org
Source:         http://resources.ovirt.org/pub/src/%{name}/%{name}-%{package_version}.tar.gz
Group:          Applications/System

BuildArch:      noarch

Requires:       bind-utils
Requires:       genisoimage
Requires:       libselinux-python
Requires:       lsof
Requires:       nmap-ncat
Requires:       openssh-server
Requires:       openssl
Requires:       pyliblzma
Requires:       python
Requires:       python-dateutil
Requires:       python-ethtool >= 0.6-3
Requires:       python-netaddr
Requires:       python-libguestfs
Requires:       python-six
Requires:       sanlock >= 2.8
Requires:       sanlock-python >= 2.8
Requires:       socat
Requires:       sudo
Requires:       libvirt-client
Requires:       m2crypto
Requires:       virt-install
Requires:       python-ovirt-engine-sdk4 >= 4.2.4
Requires:       ansible >= 2.7
# default libvirt network
Requires:       libvirt-daemon-config-network

BuildRequires:  gettext >= 0.18.2
BuildRequires:  python2-devel
BuildRequires:  pytest

%if 0%{?fedora}
Requires:       qemu-img
%endif

%if 0%{?rhel}
Requires:       qemu-img-rhev
%endif


Requires:       otopi >= 1.8
Requires:       ovirt-host-deploy >= 1.8
Requires:       ovirt-hosted-engine-ha >= 2.3.3
Requires:       ovirt-setup-lib >= 1.1
Requires:       glusterfs-cli >= 3.12.0
Requires:       vdsm-python >= 4.30
Requires(post): vdsm-python >= 4.30
Requires:       ovirt-host >= 4.3
Requires:       ovirt-ansible-hosted-engine-setup >= 1.0.21
Requires:       ovirt-ansible-engine-setup >= 1.1.9
Requires:       ovirt-ansible-repositories >= 1.1.5

Conflicts:      ovirt-engine-appliance < 4.3
Conflicts:      ovirt-engine-appliance >= 4.4


%description
Hosted Engine setup tool for oVirt project.

%prep
%setup -q -n %{name}-%{package_version}

%build
%configure \
        --docdir="%{_docdir}/%{name}-%{version}" \
        --disable-python-syntax-check \
        %{?conf}
make %{?_smp_mflags}

%check
make test

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README
%doc readme.appliance
%doc readme.rollback
%dir %{_sysconfdir}/ovirt-hosted-engine-setup.env.d
%dir %{_sysconfdir}/ovirt-hosted-engine
%ghost %attr(600, root, root) %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
%dir %attr(700, root, root) %{_localstatedir}/log/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup/answers
%{_sbindir}/hosted-engine
%{_sbindir}/ovirt-hosted-engine-setup
%{_sbindir}/ovirt-hosted-engine-cleanup
%{python_sitelib}/ovirt_hosted_engine_setup/
%{_datadir}/%{name}/
%{_mandir}/man8/*

#move to a separate package?
%{vdsmhooksdir}/before_vm_start/

%post
touch %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
chmod 600 %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
python -c '
from vdsm.tool.configurators import passwd
print((
    "[credentials-vdsm]\n"
    "authname={authname}\n"
    "password={password}\n\n"
    "[auth-libvirt-localhost]\n"
    "credentials=vdsm\n"
).format(
    authname=passwd.SASL_USERNAME,
    password=passwd.libvirt_password(),
))
' > %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf

%changelog
* Tue Jun 25 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.11-1
- 2.3.11-1

* Tue Jun 11 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.11-0.0.master
- 2.3.11-0.0.master

* Tue Jun 11 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.10-1
- 2.3.10-1

* Tue May 28 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.10-0.0.master
- 2.3.10-0.0.master

* Tue May 28 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.9-1
- 2.3.9-1

* Tue May 14 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.9-0.0.master
- 2.3.9-0.0.master

* Tue May 14 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.8-1
- 2.3.8-1

* Tue Mar 26 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.8-0.0.master
- 2.3.8-0.0.master

* Tue Mar 26 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.7-1
- 2.3.7-1

* Mon Mar 04 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.7-0.0.master
- 2.3.7-0.0.master

* Mon Mar 04 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.6-1
- 2.3.6-1

* Mon Feb 18 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.6-0.0.master
- 2.3.6-0.0.master

* Mon Feb 18 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.5-1
- 2.3.5-1

* Fri Jan 25 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.4-0.0.master
- 2.3.4-0.0.master

* Fri Jan 25 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.3-1
- 2.3.3-1

* Mon Jan 14 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.3-0.0.master
- 2.3.3-0.0.master

* Mon Jan 14 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.2-1
- 2.3.2-1

* Fri Jan 11 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.2-0.0.master
- 2.3.2-0.0.master

* Fri Jan 11 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.1-1
- 2.3.1-1

* Wed Jan 09 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.1-0.0.master
- 2.3.1-0.0.master

* Wed Jan 09 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.0-1
- 2.3.0-1

* Wed Nov 21 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.3.0-0.2.master
- 2.3.0-0.2.master

* Wed Nov 21 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.3.0-0.1.beta
- 2.3.0-0.1.beta

* Thu Feb 01 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.3.0-0.0.master
- 2.3.0-0.0.master

* Wed Jan 24 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.9-0.0.master
- 2.2.9-0.0.master

* Wed Jan 24 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.8-1
- 2.2.8-1

* Tue Jan 23 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.8-0.0.master
- 2.2.8-0.0.master

* Tue Jan 23 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.7-1
- 2.2.7-1

* Wed Jan 17 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.7-0.0.master
- 2.2.7-0.0.master

* Wed Jan 17 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.6-1
- 2.2.6-1

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.6-0.0.master
- 2.2.6-0.0.master

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.5-1
- 2.2.5-1

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.5-0.0.master
- 2.2.5-0.0.master

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.4-1
- 2.2.4-1

* Tue Dec 19 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.4-0.0.master
- 2.2.4-0.0.master

* Tue Dec 19 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.3-1
- 2.2.3-1

* Thu Dec 14 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.3-0.0.master
- 2.2.3-0.0.master

* Thu Dec 14 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.2-1
- 2.2.2-1

* Mon Dec 11 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.2-0.0.master
- 2.2.2-0.0.master

* Mon Dec 11 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.1-1
- 2.2.1-1

* Thu Nov 30 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 2.2.1-0.0.master
- 2.2.1-0.0.master

* Thu Nov 30 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 2.2.0-1
- 2.2.0-1

* Wed Dec 21 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.2.0-0.0.master
- 2.2.0-0.0.master

* Tue Jun 14 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0-0.0.master
- 2.1.0-0.0.master

* Wed Jun 08 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.0.2-0.0.master
- 2.0.0.2-0.0.master

* Wed Jun 08 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.0.1-1
- 2.0.0.1-1

* Tue May 31 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.0-1
- 2.0.0-1

* Thu Aug  6 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.0-0.0.master
- 2.0.0-0.0.master
